/*
	'3D No More' kwin client

	Copyright (C) 2002 Yuheng Xie <elephant@linux.net.cn>

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public
	License as published by the Free Software Foundation; either
	version 2 of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; see the file COPYING.  If not, write to
	the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA 02111-1307, USA.
*/

#include "config.h"

extern "C"
{
	QObject *allocate_config(KConfig *conf, QWidget *parent)
	{
		return new K3DNoMoreConfig(conf, parent);
	}
}

K3DNoMoreConfig::K3DNoMoreConfig(KConfig *conf, QWidget *parent)
	: QObject(parent)
{
	KGlobal::locale()->insertCatalogue("kwin_3dnomore_config");
	config = new KConfig("kwin3dnomorerc");
	gb = new QGroupBox(1, Qt::Horizontal, i18n("Options"), parent);
	cb3DFrame = new QCheckBox(i18n("Use &normal 3D frame instead of dashed lines"), gb);
	QWhatsThis::add(cb3DFrame, i18n(
		"When selected, the window decoration borders "
		"are drawn with normal 3D effect. Otherwise, they are "
		"drawn using dashed lines."
	));
	cbInvertGears = new QCheckBox(i18n("In&vert the gears"), gb);
	QWhatsThis::add(cbInvertGears, i18n(
		"When selected, the gears are drawn in an opposite direction."
	));
	gbColors = new QGroupBox(2, Qt::Horizontal, i18n("Colors"), parent);

	lDashedLines = new QLabel(i18n("Dashed &lines :"), gbColors);
	cbDashedLines = new KColorButton(gbColors);
	lDashedLines->setBuddy(cbDashedLines);
	QWhatsThis::add(cbDashedLines, i18n("Select the dashed lines' color."));
	lGears = new QLabel(i18n("G&ears :"), gbColors);
	cbGears = new KColorButton(gbColors);
	lGears->setBuddy(cbGears);
	QWhatsThis::add(cbGears, i18n("Select the gears' color."));

	lButtons = new QLabel(i18n("Context &Help Button :"), gbColors);
	cbButtons = new KColorButton(gbColors);
	lButtons->setBuddy(cbButtons);
	QWhatsThis::add(cbButtons, i18n("Select the context help button's color."));

	minlButtons = new QLabel(i18n("&Minimize Button :"), gbColors);
	mincbButtons = new KColorButton(gbColors);
	minlButtons->setBuddy(mincbButtons);
	QWhatsThis::add(mincbButtons, i18n("Select the minimize button's color."));

	maxlButtons = new QLabel(i18n("Ma&ximize Button :"), gbColors);
	maxcbButtons = new KColorButton(gbColors);
	maxlButtons->setBuddy(maxcbButtons);
	QWhatsThis::add(maxcbButtons, i18n("Select the maximize button's color."));

	closelButtons = new QLabel(i18n("&Close Button :"), gbColors);
	closecbButtons = new KColorButton(gbColors);
	closelButtons->setBuddy(closecbButtons);
	QWhatsThis::add(closecbButtons, i18n("Select the close button's color."));

	lDashedLinesDis = new QLabel(i18n("Dashed l&ines (disactived) :"), gbColors);
	cbDashedLinesDis = new KColorButton(gbColors);
	lDashedLinesDis->setBuddy(cbDashedLinesDis);
	QWhatsThis::add(cbDashedLinesDis, i18n("Select the dashed lines' color (disactived)."));
	lGearsDis = new QLabel(i18n("Gea&rs (disactived) :"), gbColors);
	cbGearsDis = new KColorButton(gbColors);
	lGearsDis->setBuddy(cbGearsDis);
	QWhatsThis::add(cbGearsDis, i18n("Select the gears' color (disactived)."));
	lButtonsDis = new QLabel(i18n("Bu&ttons (disactived) :"), gbColors);
	cbButtonsDis = new KColorButton(gbColors);
	lButtonsDis->setBuddy(cbButtonsDis);
	QWhatsThis::add(cbButtonsDis, i18n("Select the buttons' color (disactived)."));

	load(conf);
	connect(cb3DFrame, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
	connect(cbInvertGears, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
	connect(cbDashedLines, SIGNAL(changed(const QColor &)),
		this, SLOT(slotSelectionChanged(const QColor &)));
	connect(cbGears, SIGNAL(changed(const QColor &)),
		this, SLOT(slotSelectionChanged(const QColor &)));
	connect(cbButtons, SIGNAL(changed(const QColor &)),
		this, SLOT(slotSelectionChanged(const QColor &)));
	connect(mincbButtons, SIGNAL(changed(const QColor &)),
		this, SLOT(slotSelectionChanged(const QColor &)));
	connect(maxcbButtons, SIGNAL(changed(const QColor &)),
		this, SLOT(slotSelectionChanged(const QColor &)));
	connect(closecbButtons, SIGNAL(changed(const QColor &)),
		this, SLOT(slotSelectionChanged(const QColor &)));
	connect(cbDashedLinesDis, SIGNAL(changed(const QColor &)),
		this, SLOT(slotSelectionChanged(const QColor &)));
	connect(cbGearsDis, SIGNAL(changed(const QColor &)),
		this, SLOT(slotSelectionChanged(const QColor &)));
	connect(cbButtonsDis, SIGNAL(changed(const QColor &)),
		this, SLOT(slotSelectionChanged(const QColor &)));
	gb->show();
	gbColors->show();
}

K3DNoMoreConfig::~K3DNoMoreConfig()
{
	delete cb3DFrame;
	delete cbInvertGears;
	delete cbDashedLines;
	delete cbGears;
	delete cbButtons;
	delete mincbButtons;
	delete maxcbButtons;
	delete closecbButtons;
	delete cbDashedLinesDis;
	delete cbGearsDis;
	delete cbButtonsDis;
	delete gb;
	delete gbColors;
	delete config;
}

void K3DNoMoreConfig::slotSelectionChanged(const QColor &newColor)
{
	emit changed();
}

void K3DNoMoreConfig::slotSelectionChanged()
{
	emit changed();
}

void K3DNoMoreConfig::load(KConfig *conf)
{
	config->setGroup("General");
	bool use3dframe = config->readBoolEntry("Use3DFrame", false);
	cb3DFrame->setChecked(use3dframe);
	bool invertgears = config->readBoolEntry("InvertGears", false);
	cbInvertGears->setChecked(invertgears);
	QColor color;

	color = config->readColorEntry("DashedLinesColor", &QColor(40, 70, 100));
	cbDashedLines->setColor(color);
	color = config->readColorEntry("GearsColor", &QColor(168, 204, 240));
	cbGears->setColor(color);
	color = config->readColorEntry("ButtonsColor", &QColor(90, 159, 228));
	cbButtons->setColor(color);
	color = config->readColorEntry("minButtonsColor", &QColor(90, 159, 228));
	mincbButtons->setColor(color);
	color = config->readColorEntry("maxButtonsColor", &QColor(90, 159, 228));
	maxcbButtons->setColor(color);
	color = config->readColorEntry("closeButtonsColor", &QColor(90, 159, 228));
	closecbButtons->setColor(color);

	color = config->readColorEntry("DashedLinesColorDis", &QColor(100, 100, 100));
	cbDashedLinesDis->setColor(color);
	color = config->readColorEntry("GearsColorDis", &QColor(220, 220, 220));
	cbGearsDis->setColor(color);
	color = config->readColorEntry("ButtonsColorDis", &QColor(188, 188, 188));
	cbButtonsDis->setColor(color);
}

void K3DNoMoreConfig::save(KConfig *conf)
{
	config->setGroup("General");
	config->writeEntry("Use3DFrame", cb3DFrame->isChecked());
	config->writeEntry("InvertGears", cbInvertGears->isChecked());
	config->writeEntry("DashedLinesColor", cbDashedLines->color());
	config->writeEntry("GearsColor", cbGears->color());
	config->writeEntry("ButtonsColor", cbButtons->color());
	config->writeEntry("minButtonsColor", mincbButtons->color());
	config->writeEntry("maxButtonsColor", maxcbButtons->color());
	config->writeEntry("closeButtonsColor", closecbButtons->color());
	config->writeEntry("DashedLinesColorDis", cbDashedLinesDis->color());
	config->writeEntry("GearsColorDis", cbGearsDis->color());
	config->writeEntry("ButtonsColorDis", cbButtonsDis->color());
	config->sync();
}

void K3DNoMoreConfig::defaults()
{
	cb3DFrame->setChecked(false);
	cbInvertGears->setChecked(false);
	cbDashedLines->setColor(QColor(40, 70, 100));
	cbGears->setColor(QColor(168, 204, 240));
	cbButtons->setColor(QColor(90, 159, 228));
	mincbButtons->setColor(QColor(90, 159, 228));
	maxcbButtons->setColor(QColor(90, 159, 228));
	closecbButtons->setColor(QColor(90, 159, 228));
	cbDashedLinesDis->setColor(QColor(100, 100, 100));
	cbGearsDis->setColor(QColor(220, 220, 220));
	cbButtonsDis->setColor(QColor(188, 188, 188));
}

// vim: ts=2
